@@ -16,9 +16,16 @@ from langgraph_api.feature_flags import USE_RUNTIME_CONTEXT_API
 from langgraph_api.graph import get_assistant_id, get_graph
 from langgraph_api.js.base import BaseRemotePregel
 from langgraph_api.route import ApiRequest, ApiResponse, ApiRoute
+from langgraph_api.schema import ASSISTANT_FIELDS
 from langgraph_api.serde import ajson_loads
-from langgraph_api.utils import fetchone, get_pagination_headers, validate_uuid
+from langgraph_api.utils import (
+    fetchone,
+    get_pagination_headers,
+    validate_select_columns,
+    validate_uuid,
+)
 from langgraph_api.validation import (
+    AssistantCountRequest,
     AssistantCreate,
     AssistantPatch,
     AssistantSearchRequest,
@@ -61,7 +68,8 @@ def _get_configurable_jsonschema(graph: Pregel) -> dict:
     in favor of graph.get_context_jsonschema().
     """
     # Otherwise, use the config_schema method.
-    config_schema = graph.config_schema()
+    # TODO: Remove this when we no longer support langgraph < 0.6
+    config_schema = graph.config_schema()  # type: ignore[deprecated]
     model_fields = getattr(config_schema, "model_fields", None) or getattr(
         config_schema, "__fields__", None
     )
@@ -74,9 +82,12 @@ def _get_configurable_jsonschema(graph: Pregel) -> dict:
                 json_schema["properties"].pop(key, None)
         # The type name of the configurable type is not preserved.
         # We'll add it back to the schema if we can.
-        if hasattr(graph, "config_type") and graph.config_type is not None:
-            if hasattr(graph.config_type, "__name__"):
-                json_schema["title"] = graph.config_type.__name__
+        if (
+            hasattr(graph, "config_type")
+            and graph.config_type is not None
+            and hasattr(graph.config_type, "__name__")
+        ):
+            json_schema["title"] = graph.config_type.__name__
         return json_schema
     # If the schema does not have a configurable field, return an empty schema.
     return {}
@@ -87,11 +98,11 @@ def _state_jsonschema(graph: Pregel) -> dict | None:
     for k in graph.stream_channels_list:
         v = graph.channels[k]
         try:
-            create_model(k, __root__=(v.UpdateType, None)).schema()
+            create_model(k, __root__=(v.UpdateType, None)).model_json_schema()
             fields[k] = (v.UpdateType, None)
         except Exception:
             fields[k] = (Any, None)
-    return create_model(graph.get_name("State"), **fields).schema()
+    return create_model(graph.get_name("State"), **fields).model_json_schema()
 
 
 def _graph_schemas(graph: Pregel) -> dict:
@@ -132,7 +143,7 @@ def _graph_schemas(graph: Pregel) -> dict:
             logger.warning(
                 f"Failed to get context schema for graph {graph.name} with error: `{str(e)}`"
             )
-            context_schema = graph.config_schema()
+            context_schema = graph.config_schema()  # type: ignore[deprecated]
     else:
         context_schema = None
 
@@ -172,6 +183,7 @@ async def search_assistants(
 ) -> ApiResponse:
     """List assistants."""
     payload = await request.json(AssistantSearchRequest)
+    select = validate_select_columns(payload.get("select") or None, ASSISTANT_FIELDS)
     offset = int(payload.get("offset") or 0)
     async with connect() as conn:
         assistants_iter, next_offset = await Assistants.search(
@@ -182,6 +194,7 @@ async def search_assistants(
             offset=offset,
             sort_by=payload.get("sort_by"),
             sort_order=payload.get("sort_order"),
+            select=select,
         )
     assistants, response_headers = await get_pagination_headers(
         assistants_iter, next_offset, offset
@@ -189,6 +202,21 @@ async def search_assistants(
     return ApiResponse(assistants, headers=response_headers)
 
 
+@retry_db
+async def count_assistants(
+    request: ApiRequest,
+) -> ApiResponse:
+    """Count assistants."""
+    payload = await request.json(AssistantCountRequest)
+    async with connect() as conn:
+        count = await Assistants.count(
+            conn,
+            graph_id=payload.get("graph_id"),
+            metadata=payload.get("metadata"),
+        )
+    return ApiResponse(count)
+
+
 @retry_db
 async def get_assistant(
     request: ApiRequest,
@@ -238,18 +266,16 @@ async def get_assistant_graph(
             drawable_graph = await graph.fetch_graph(xray=xray)
             json_graph = drawable_graph.to_json()
             for node in json_graph.get("nodes", []):
-                if data := node.get("data"):
-                    if isinstance(data, dict):
-                        data.pop("id", None)
+                if (data := node.get("data")) and isinstance(data, dict):
+                    data.pop("id", None)
             return ApiResponse(json_graph)
 
         try:
             drawable_graph = await graph.aget_graph(xray=xray)
             json_graph = drawable_graph.to_json()
             for node in json_graph.get("nodes", []):
-                if data := node.get("data"):
-                    if isinstance(data, dict):
-                        data.pop("id", None)
+                if (data := node.get("data")) and isinstance(data, dict):
+                    data.pop("id", None)
             return ApiResponse(json_graph)
         except NotImplementedError:
             raise HTTPException(
@@ -366,7 +392,7 @@ async def patch_assistant(
 
 
 @retry_db
-async def delete_assistant(request: ApiRequest) -> ApiResponse:
+async def delete_assistant(request: ApiRequest) -> Response:
     """Delete an assistant by ID."""
     assistant_id = request.path_params["assistant_id"]
     validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
@@ -414,6 +440,7 @@ async def set_latest_assistant_version(request: ApiRequest) -> ApiResponse:
 assistants_routes: list[BaseRoute] = [
     ApiRoute("/assistants", create_assistant, methods=["POST"]),
     ApiRoute("/assistants/search", search_assistants, methods=["POST"]),
+    ApiRoute("/assistants/count", count_assistants, methods=["POST"]),
     ApiRoute(
         "/assistants/{assistant_id}/latest",
         set_latest_assistant_version,
