@@ -1,7 +1,7 @@
 import asyncio
 import concurrent.futures
 from collections.abc import AsyncIterator, Coroutine
-from contextlib import AbstractAsyncContextManager
+from contextlib import AbstractAsyncContextManager, suppress
 from functools import partial
 from typing import Any, Generic, TypeVar
 
@@ -26,10 +26,8 @@ def get_event_loop() -> asyncio.AbstractEventLoop:
 
 
 async def sleep_if_not_done(delay: float, done: asyncio.Event) -> None:
-    try:
+    with suppress(TimeoutError):
         await asyncio.wait_for(done.wait(), delay)
-    except TimeoutError:
-        pass
 
 
 class ValueEvent(asyncio.Event):
@@ -95,14 +93,13 @@ PENDING_TASKS = set()
 
 
 def _create_task_done_callback(
-    ignore_exceptions: tuple[Exception, ...],
+    ignore_exceptions: tuple[type[Exception], ...],
     task: asyncio.Task | asyncio.Future,
 ) -> None:
     PENDING_TASKS.discard(task)
     try:
-        if exc := task.exception():
-            if not isinstance(exc, ignore_exceptions):
-                logger.exception("asyncio.task failed", exc_info=exc)
+        if (exc := task.exception()) and not isinstance(exc, ignore_exceptions):
+            logger.exception("asyncio.task failed", exc_info=exc)
     except asyncio.CancelledError:
         pass
 
@@ -119,7 +116,7 @@ def create_task(
 
 def run_coroutine_threadsafe(
     coro: Coroutine[Any, Any, T], ignore_exceptions: tuple[type[Exception], ...] = ()
-) -> concurrent.futures.Future[T | None]:
+) -> concurrent.futures.Future[T] | concurrent.futures.Future[None]:
     if _MAIN_LOOP is None:
         raise RuntimeError("No event loop set")
     future = asyncio.run_coroutine_threadsafe(coro, _MAIN_LOOP)
@@ -176,16 +173,13 @@ class SimpleTaskGroup(AbstractAsyncContextManager["SimpleTaskGroup"]):
         self.taskgroup_name = f" {taskgroup_name} " if taskgroup_name else ""
 
     def _create_task_done_callback(
-        self, ignore_exceptions: tuple[Exception, ...], task: asyncio.Task
+        self, ignore_exceptions: tuple[type[Exception], ...], task: asyncio.Task
     ) -> None:
-        try:
+        with suppress(AttributeError):
             self.tasks.remove(task)
-        except AttributeError:
-            pass
         try:
-            if exc := task.exception():
-                if not isinstance(exc, ignore_exceptions):
-                    logger.exception("asyncio.task failed in task group", exc_info=exc)
+            if (exc := task.exception()) and not isinstance(exc, ignore_exceptions):
+                logger.exception("asyncio.task failed in task group", exc_info=exc)
         except asyncio.CancelledError:
             pass
 
@@ -226,7 +220,7 @@ def to_aiter(*args: T) -> AsyncIterator[T]:
 V = TypeVar("V")
 
 
-class aclosing(Generic[V], AbstractAsyncContextManager):
+class aclosing(Generic[V], AbstractAsyncContextManager[V]):
     """Async context manager for safely finalizing an asynchronously cleaned-up
     resource such as an async generator, calling its ``aclose()`` method.
 
@@ -255,14 +249,16 @@ class aclosing(Generic[V], AbstractAsyncContextManager):
         await self.thing.aclose()
 
 
-async def aclosing_aiter(aiter: AsyncIterator[T]) -> AsyncIterator[T]:
-    if hasattr(aiter, "__aenter__"):
-        async with aiter:
-            async for item in aiter:
+async def aclosing_aiter(
+    aiterator: AsyncIterator[T],
+) -> AsyncIterator[T]:
+    if hasattr(aiterator, "__aenter__"):
+        async with aiterator:  # type: ignore[invalid-context-manager]
+            async for item in aiterator:
                 yield item
     else:
-        async with aclosing(aiter):
-            async for item in aiter:
+        async with aclosing(aiterator):
+            async for item in aiterator:
                 yield item
 
 
@@ -284,13 +280,8 @@ class AsyncQueue(Generic[T], asyncio.Queue[T]):
                 await getter
             except:
                 getter.cancel()  # Just in case getter is not done yet.
-                try:
-                    # Clean self._getters from canceled getters.
+                with suppress(ValueError):
                     self._getters.remove(getter)
-                except ValueError:
-                    # The getter could be removed from self._getters by a
-                    # previous put_nowait call.
-                    pass
                 if not self.empty() and not getter.cancelled():
                     # We were woken up by put_nowait(), but can't take
                     # the call.  Wake up the next in line.
