@@ -239,26 +239,24 @@ def _get_custom_auth_middleware(
 
 @functools.lru_cache(maxsize=1)
 def _get_auth_instance(path: str | None = None) -> Auth | Literal["js"] | None:
-    if path is not None:
-        auth_instance = _load_auth_obj(path)
-    else:
-        auth_instance = None
+    auth_instance = _load_auth_obj(path) if path is not None else None
 
     if auth_instance == "js":
         return auth_instance
-
+    deps = None
     if auth_instance is not None and (
         deps := _get_dependencies(auth_instance._authenticate_handler)
     ):
         auth_instance._authenticate_handler = _solve_fastapi_dependencies(
-            auth_instance._authenticate_handler, deps
+            auth_instance._authenticate_handler,  # type: ignore[invalid-argument-type]
+            deps,
         )
     logger.info(f"Loaded auth instance from path {path}: {auth_instance}")
     return auth_instance
 
 
 def _extract_arguments_from_scope(
-    scope: dict[str, Any],
+    scope: Mapping[str, Any],
     param_names: set[str],
     request: Request | None = None,
     response: Response | None = None,
@@ -283,7 +281,11 @@ def _extract_arguments_from_scope(
     if "path" in param_names:
         args["path"] = scope["path"]
     if "query_params" in param_names:
-        args["query_params"] = QueryParams(scope.get("query_string"))
+        query_params = scope.get("query_string")
+        if query_params:
+            args["query_params"] = QueryParams(query_params)
+        else:
+            args["query_params"] = QueryParams()
     if "headers" in param_names:
         args["headers"] = dict(scope.get("headers", {}))
     if "authorization" in param_names:
@@ -520,6 +522,12 @@ class ProxyUser(BaseUser):
         """Proxy any other attributes to the underlying user object."""
         return getattr(self._user, name)
 
+    def __iter__(self):
+        return iter(self._user)
+
+    def __len__(self):
+        return len(self._user)
+
     def __str__(self) -> str:
         return f"{self._user}"
 
@@ -595,7 +603,7 @@ def _load_auth_obj(path: str) -> Auth | Literal["js"]:
                 raise ValueError(f"Could not load file: {module_name}")
             module = importlib.util.module_from_spec(modspec)
             sys.modules[modname] = module
-            modspec.loader.exec_module(module)
+            modspec.loader.exec_module(module)  # type: ignore[possibly-unbound-attribute]
         else:
             # Load from Python module
             module = importlib.import_module(module_name)
