@@ -11,10 +11,8 @@ if not (
 
 import asyncio
 import contextlib
-import http.server
 import json
 import logging.config
-import os
 import pathlib
 import signal
 from contextlib import asynccontextmanager
@@ -22,6 +20,7 @@ from typing import cast
 
 import structlog
 
+from langgraph_runtime.database import pool_stats
 from langgraph_runtime.lifespan import lifespan
 from langgraph_runtime.metrics import get_metrics
 
@@ -29,69 +28,68 @@ logger = structlog.stdlib.get_logger(__name__)
 
 
 async def health_and_metrics_server():
+    import uvicorn
+    from starlette.applications import Starlette
+    from starlette.responses import JSONResponse, PlainTextResponse
+    from starlette.routing import Route
+
     port = int(os.getenv("PORT", "8080"))
-    ok = json.dumps({"status": "ok"}).encode()
-    ok_len = str(len(ok))
 
-    class HealthAndMetricsHandler(http.server.SimpleHTTPRequestHandler):
-        def log_message(self, format, *args):
-            # Skip logging for /ok and /metrics endpoints
-            if getattr(self, "path", None) in ["/ok", "/metrics"]:
-                return
-            # Log other requests normally
-            super().log_message(format, *args)
+    async def health_endpoint(request):
+        return JSONResponse({"status": "ok"})
 
-        def do_GET(self):
-            path = getattr(self, "path", None)
-            if path == "/ok":
-                self.send_response(200)
-                self.send_header("Content-Type", "application/json")
-                self.send_header("Content-Length", ok_len)
-                self.end_headers()
-                self.wfile.write(ok)
-            elif path == "/metrics":
-                metrics = get_metrics()
-                worker_metrics = cast(dict[str, int], metrics["workers"])
-                workers_max = worker_metrics["max"]
-                workers_active = worker_metrics["active"]
-                workers_available = worker_metrics["available"]
+    async def metrics_endpoint(request):
+        metrics = get_metrics()
+        worker_metrics = cast(dict[str, int], metrics["workers"])
+        workers_max = worker_metrics["max"]
+        workers_active = worker_metrics["active"]
+        workers_available = worker_metrics["available"]
 
-                project_id = os.getenv("LANGSMITH_HOST_PROJECT_ID")
-                revision_id = os.getenv("LANGSMITH_HOST_REVISION_ID")
+        project_id = os.getenv("LANGSMITH_HOST_PROJECT_ID")
+        revision_id = os.getenv("LANGSMITH_HOST_REVISION_ID")
 
-                metrics = [
-                    "# HELP lg_api_workers_max The maximum number of workers available.",
-                    "# TYPE lg_api_workers_max gauge",
-                    f'lg_api_workers_max{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_max}',
-                    "# HELP lg_api_workers_active The number of currently active workers.",
-                    "# TYPE lg_api_workers_active gauge",
-                    f'lg_api_workers_active{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_active}',
-                    "# HELP lg_api_workers_available The number of available (idle) workers.",
-                    "# TYPE lg_api_workers_available gauge",
-                    f'lg_api_workers_available{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_available}',
-                ]
+        metrics_lines = [
+            "# HELP lg_api_workers_max The maximum number of workers available.",
+            "# TYPE lg_api_workers_max gauge",
+            f'lg_api_workers_max{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_max}',
+            "# HELP lg_api_workers_active The number of currently active workers.",
+            "# TYPE lg_api_workers_active gauge",
+            f'lg_api_workers_active{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_active}',
+            "# HELP lg_api_workers_available The number of available (idle) workers.",
+            "# TYPE lg_api_workers_available gauge",
+            f'lg_api_workers_available{{project_id="{project_id}", revision_id="{revision_id}"}} {workers_available}',
+        ]
 
-                metrics_response = "\n".join(metrics).encode()
-                metrics_len = str(len(metrics_response))
+        metrics_lines.extend(
+            pool_stats(
+                project_id=project_id,
+                revision_id=revision_id,
+            )
+        )
 
-                self.send_response(200)
-                self.send_header(
-                    "Content-Type", "text/plain; version=0.0.4; charset=utf-8"
-                )
-                self.send_header("Content-Length", metrics_len)
-                self.end_headers()
-                self.wfile.write(metrics_response)
-            else:
-                self.send_error(http.HTTPStatus.NOT_FOUND)
+        return PlainTextResponse(
+            "\n".join(metrics_lines),
+            media_type="text/plain; version=0.0.4; charset=utf-8",
+        )
 
-    with http.server.ThreadingHTTPServer(
-        ("0.0.0.0", port), HealthAndMetricsHandler
-    ) as httpd:
-        logger.info(f"Health and metrics server started at http://0.0.0.0:{port}")
-        try:
-            await asyncio.to_thread(httpd.serve_forever)
-        finally:
-            httpd.shutdown()
+    app = Starlette(
+        routes=[
+            Route("/ok", health_endpoint),
+            Route("/metrics", metrics_endpoint),
+        ]
+    )
+
+    config = uvicorn.Config(
+        app,
+        host="0.0.0.0",
+        port=port,
+        log_level="error",
+        access_log=False,
+    )
+    server = uvicorn.Server(config)
+
+    logger.info(f"Health and metrics server started at http://0.0.0.0:{port}")
+    await server.serve()
 
 
 async def entrypoint(
